==> mktcenter-service-threetree-1.0-20250915.094325-10-sources.jar: com/bizvane/mktcenterservice/models/po/MktActivityCertificationRecordPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.math.BigDecimal;
import java.util.Date;

public class MktActivityCertificationRecordPO {
    private Long mktActivityCertificationRecordId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long mktActivityCertificationId;

    private String membersCode;

    private String cardNo;

    private String memberName;

    private String memberPhone;

    private String memberPhoto;

    private Long certificationTypeId;

    private String gender;

    private Date birthday;

    private String idCardNo;

    private String email;

    private String eduLevel;

    private String firstWorkDate;

    private String workCompany;

    private Date applyTime;

    private Date signInTime;

    private Integer applyState;

    private BigDecimal theoreticalScore;

    private BigDecimal practicalScore;

    private Integer certificationState;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktActivityCertificationRecordId() {
        return mktActivityCertificationRecordId;
    }

    public void setMktActivityCertificationRecordId(Long mktActivityCertificationRecordId) {
        this.mktActivityCertificationRecordId = mktActivityCertificationRecordId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getMktActivityCertificationId() {
        return mktActivityCertificationId;
    }

    public void setMktActivityCertificationId(Long mktActivityCertificationId) {
        this.mktActivityCertificationId = mktActivityCertificationId;
    }

    public String getMembersCode() {
        return membersCode;
    }

    public void setMembersCode(String membersCode) {
        this.membersCode = membersCode == null ? null : membersCode.trim();
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo == null ? null : cardNo.trim();
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName == null ? null : memberName.trim();
    }

    public String getMemberPhone() {
        return memberPhone;
    }

    public void setMemberPhone(String memberPhone) {
        this.memberPhone = memberPhone == null ? null : memberPhone.trim();
    }

    public String getMemberPhoto() {
        return memberPhoto;
    }

    public void setMemberPhoto(String memberPhoto) {
        this.memberPhoto = memberPhoto == null ? null : memberPhoto.trim();
    }

    public Long getCertificationTypeId() {
        return certificationTypeId;
    }

    public void setCertificationTypeId(Long certificationTypeId) {
        this.certificationTypeId = certificationTypeId;
    }

    public String getGender() {
        return gender;
    }

    public void setGender(String gender) {
        this.gender = gender == null ? null : gender.trim();
    }

    public Date getBirthday() {
        return birthday;
    }

    public void setBirthday(Date birthday) {
        this.birthday = birthday;
    }

    public String getIdCardNo() {
        return idCardNo;
    }

    public void setIdCardNo(String idCardNo) {
        this.idCardNo = idCardNo == null ? null : idCardNo.trim();
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email == null ? null : email.trim();
    }

    public String getEduLevel() {
        return eduLevel;
    }

    public void setEduLevel(String eduLevel) {
        this.eduLevel = eduLevel == null ? null : eduLevel.trim();
    }

    public String getFirstWorkDate() {
        return firstWorkDate;
    }

    public void setFirstWorkDate(String firstWorkDate) {
        this.firstWorkDate = firstWorkDate == null ? null : firstWorkDate.trim();
    }

    public String getWorkCompany() {
        return workCompany;
    }

    public void setWorkCompany(String workCompany) {
        this.workCompany = workCompany == null ? null : workCompany.trim();
    }

    public Date getApplyTime() {
        return applyTime;
    }

    public void setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
    }

    public Date getSignInTime() {
        return signInTime;
    }

    public void setSignInTime(Date signInTime) {
        this.signInTime = signInTime;
    }

    public Integer getApplyState() {
        return applyState;
    }

    public void setApplyState(Integer applyState) {
        this.applyState = applyState;
    }

    public BigDecimal getTheoreticalScore() {
        return theoreticalScore;
    }

    public void setTheoreticalScore(BigDecimal theoreticalScore) {
        this.theoreticalScore = theoreticalScore;
    }

    public BigDecimal getPracticalScore() {
        return practicalScore;
    }

    public void setPracticalScore(BigDecimal practicalScore) {
        this.practicalScore = practicalScore;
    }

    public Integer getCertificationState() {
        return certificationState;
    }

    public void setCertificationState(Integer certificationState) {
        this.certificationState = certificationState;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}

==> mktcenter-service-threetree-1.0-20250925.075605-23-sources.jar: com/bizvane/mktcenterservice/models/po/MktActivityCertificationRecordPO.java <==
package com.bizvane.mktcenterservice.models.po;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

@Data
public class MktActivityCertificationRecordPO {
    private Long mktActivityCertificationRecordId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long mktActivityCertificationId;

    private String membersCode;

    private String cardNo;

    private String memberName;

    private String memberPhone;

    private String memberPhoto;

    private Long certificationTypeId;

    @ApiModelProperty(value = "性别,女:1 男:2 未知:3")
    private String gender;

    private Date birthday;

    private String idCardNo;

    private String email;

    private String eduLevel;

    private String firstWorkDate;

    private String workCompany;

    private Date applyTime;

    private Date signInTime;

    private Integer applyState;

    private BigDecimal theoreticalScore;

    private BigDecimal practicalScore;

    private Integer certificationState;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktActivityCertificationRecordId() {
        return mktActivityCertificationRecordId;
    }

    public void setMktActivityCertificationRecordId(Long mktActivityCertificationRecordId) {
        this.mktActivityCertificationRecordId = mktActivityCertificationRecordId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getMktActivityCertificationId() {
        return mktActivityCertificationId;
    }

    public void setMktActivityCertificationId(Long mktActivityCertificationId) {
        this.mktActivityCertificationId = mktActivityCertificationId;
    }

    public String getMembersCode() {
        return membersCode;
    }

    public void setMembersCode(String membersCode) {
        this.membersCode = membersCode == null ? null : membersCode.trim();
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo == null ? null : cardNo.trim();
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName == null ? null : memberName.trim();
    }

    public String getMemberPhone() {
        return memberPhone;
    }

    public void setMemberPhone(String memberPhone) {
        this.memberPhone = memberPhone == null ? null : memberPhone.trim();
    }

    public String getMemberPhoto() {
        return memberPhoto;
    }

    public void setMemberPhoto(String memberPhoto) {
        this.memberPhoto = memberPhoto == null ? null : memberPhoto.trim();
    }

    public Long getCertificationTypeId() {
        return certificationTypeId;
    }

    public void setCertificationTypeId(Long certificationTypeId) {
        this.certificationTypeId = certificationTypeId;
    }

    public String getGender() {
        return gender;
    }

    public void setGender(String gender) {
        this.gender = gender == null ? null : gender.trim();
    }

    public Date getBirthday() {
        return birthday;
    }

    public void setBirthday(Date birthday) {
        this.birthday = birthday;
    }

    public String getIdCardNo() {
        return idCardNo;
    }

    public void setIdCardNo(String idCardNo) {
        this.idCardNo = idCardNo == null ? null : idCardNo.trim();
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email == null ? null : email.trim();
    }

    public String getEduLevel() {
        return eduLevel;
    }

    public void setEduLevel(String eduLevel) {
        this.eduLevel = eduLevel == null ? null : eduLevel.trim();
    }

    public String getFirstWorkDate() {
        return firstWorkDate;
    }

    public void setFirstWorkDate(String firstWorkDate) {
        this.firstWorkDate = firstWorkDate == null ? null : firstWorkDate.trim();
    }

    public String getWorkCompany() {
        return workCompany;
    }

    public void setWorkCompany(String workCompany) {
        this.workCompany = workCompany == null ? null : workCompany.trim();
    }

    public Date getApplyTime() {
        return applyTime;
    }

    public void setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
    }

    public Date getSignInTime() {
        return signInTime;
    }

    public void setSignInTime(Date signInTime) {
        this.signInTime = signInTime;
    }

    public Integer getApplyState() {
        return applyState;
    }

    public void setApplyState(Integer applyState) {
        this.applyState = applyState;
    }

    public BigDecimal getTheoreticalScore() {
        return theoreticalScore;
    }

    public void setTheoreticalScore(BigDecimal theoreticalScore) {
        this.theoreticalScore = theoreticalScore;
    }

    public BigDecimal getPracticalScore() {
        return practicalScore;
    }

    public void setPracticalScore(BigDecimal practicalScore) {
        this.practicalScore = practicalScore;
    }

    public Integer getCertificationState() {
        return certificationState;
    }

    public void setCertificationState(Integer certificationState) {
        this.certificationState = certificationState;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}
